Askbot Dependencies — Askbot 0.12.7 documentation

# Askbot Project Documentation

Home | Ask Questions | Consulting Services | Documentation | Contribute | Contact

# Askbot Dependencies

Askbot depends on quite a few other packages. Normally those dependencies will be automatically resolved with setuptools (i.e. when you run easy_install or python setup.py install).

However, if something does not go well - e.g. some dependency package site is not accessible, please download and install them manually:

- django-2.2.2

- django-debug-toolbar

- recaptcha-client

- markdown2

- html5lib

- python-openid

- django-keyedcache

- django-threaded-multihost

- mysql-python

If any of the provided links do not work please try to look up those packages or notify askbot maintainers at admin@askbot.org.